@@ -22,6 +22,7 @@ from django.db.models import (
     Model,
     Q,
     Sum,
+    Value,
 )
 from django.db.models.functions import TruncDate
 from django.utils import timezone
@@ -154,7 +155,7 @@ class UserProfile(guardian.mixins.GuardianUserMixin, PermissionsMixin, AbstractB
         from ephios.core.models import AbstractParticipation
 
         participations = (
-            self.participations.filter(state=AbstractParticipation.States.CONFIRMED)
+            self.participations.filter(state=AbstractParticipation.States.CONFIRMED, finished=True)
             .annotate(
                 duration=ExpressionWrapper(
                     (F("end_time") - F("start_time")),
@@ -162,12 +163,14 @@ class UserProfile(guardian.mixins.GuardianUserMixin, PermissionsMixin, AbstractB
                 ),
                 date=ExpressionWrapper(TruncDate(F("start_time")), output_field=DateField()),
                 reason=F("shift__event__title"),
+                type=Value("event"),
+                origin_id=F("shift__event__pk"),
             )
-            .values("duration", "date", "reason")
-        )
-        workinghours = self.workinghours_set.annotate(duration=F("hours")).values(
-            "duration", "date", "reason"
+            .values("duration", "date", "reason", "type", "origin_id")
         )
+        workinghours = self.workinghours_set.annotate(
+            duration=F("hours"), type=Value("request"), origin_id=F("pk")
+        ).values("duration", "date", "reason", "type", "origin_id")
         hour_sum = (
             participations.aggregate(Sum("duration"))["duration__sum"] or datetime.timedelta()
         ) + datetime.timedelta(
@@ -225,7 +228,7 @@ class QualificationManager(models.Manager):
 class Qualification(Model):
     uuid = models.UUIDField(unique=True, default=uuid.uuid4, verbose_name="UUID")
     title = CharField(_("title"), max_length=254)
-    abbreviation = CharField(max_length=254)
+    abbreviation = CharField(max_length=254, verbose_name=_("Abbreviation"))
     category = ForeignKey(
         QualificationCategory,
         on_delete=models.CASCADE,
@@ -233,7 +236,12 @@ class Qualification(Model):
         verbose_name=_("category"),
     )
     includes = models.ManyToManyField(
-        "self", related_name="included_by", symmetrical=False, blank=True
+        "self",
+        related_name="included_by",
+        verbose_name=_("Included"),
+        help_text=_("other qualifications that this qualification includes"),
+        symmetrical=False,
+        blank=True,
     )
     is_imported = models.BooleanField(verbose_name=_("imported"), default=True)
 
@@ -429,13 +437,16 @@ register_model_for_logging(
 
 class WorkingHours(Model):
     user = models.ForeignKey(get_user_model(), on_delete=models.CASCADE)
-    hours = models.DecimalField(decimal_places=2, max_digits=7)
-    reason = models.CharField(max_length=1024, default="")
+    hours = models.DecimalField(decimal_places=2, max_digits=7, verbose_name=_("Hours of work"))
+    reason = models.CharField(max_length=1024, default="", verbose_name=_("Occasion"))
     date = models.DateField()
 
     class Meta:
         db_table = "workinghours"
 
+    def __str__(self):
+        return f"{self.hours} hours for {self.user} because of {self.reason} on {self.date}"
+
 
 class Notification(Model):
     slug = models.SlugField(max_length=255)
