@@ -84,7 +84,7 @@ class ProfileUpdateNotification(AbstractNotificationHandler):
 
     @classmethod
     def get_url(cls, notification):
-        return urljoin(settings.GET_SITE_URL(), reverse("core:profile"))
+        return urljoin(settings.GET_SITE_URL(), reverse("core:settings_personal_data"))
 
 
 class NewProfileNotification(AbstractNotificationHandler):
@@ -338,9 +338,12 @@ class ResponsibleParticipationRequestedNotification(ResponsibleMixin, AbstractNo
         participation = AbstractParticipation.objects.get(
             id=notification.data.get("participation_id")
         )
-        if participation.shift.signup_method.uses_requested_state:
+        if (
+            participation.shift.signup_method.uses_requested_state
+            and participation.state != AbstractParticipation.States.CONFIRMED
+        ):
             return _(
-                "{participant} has requested a participation for {shift}. You can decide about it at {disposition_url}"
+                "{participant} has requested a participation for {shift}. You can decide about it at {disposition_url}."
             ).format(
                 shift=participation.shift,
                 participant=participation.participant,
@@ -466,6 +469,21 @@ class CustomEventParticipantNotification(AbstractNotificationHandler):
                     ),
                 )
             )
+        for responsible in get_users_with_perms(
+            event, with_superusers=False, only_with_perms_in=["change_event"]
+        ):
+            notifications.append(
+                Notification(
+                    slug=cls.slug,
+                    user=responsible,
+                    data=dict(
+                        email=responsible.email,
+                        event_id=event.id,
+                        content=content,
+                        event_title=event.title,
+                    ),
+                )
+            )
         Notification.objects.bulk_create(notifications)
 
     @classmethod
