@@ -1,20 +1,11 @@
 import json
 
 from django import forms
-from dynamic_preferences.types import (
-    BasePreferenceType,
-    BaseSerializer,
-    ModelMultipleChoicePreference,
-)
+from dynamic_preferences.types import BasePreferenceType, BaseSerializer
 
 from ephios.extra.json import CustomJSONDecoder, CustomJSONEncoder
 
 
-class CustomModelMultipleChoicePreference(ModelMultipleChoicePreference):
-    def _setup_signals(self):
-        pass
-
-
 class JSONSerializer(BaseSerializer):
     @classmethod
     def clean_to_db_value(cls, value):
